<?php

declare(strict_types=1);

use Illuminate\Support\Facades\Route;

Route::name('admin.')->group(function () {
    Route::namespace('Dashboard')->middleware('auth')->group(function (): void {
        Route::get('', 'AdminPanelController')->name('home');

        Route::name('note.')->prefix('note')->group(function (): void {
            Route::get('', 'NoteController@index')
                ->name('index');
            Route::get('create', 'NoteController@create')
                ->name('create');
            Route::post('', 'NoteController@store')
                ->name('store');
            Route::get('{note}', 'NoteController@show')
                ->name('show');
            Route::get('{note}/edit', 'NoteController@edit')
                ->name('edit');
            Route::put('{note}', 'NoteController@update')
                ->name('update');
            Route::get('{note}/delete', 'NoteController@delete')
                ->name('delete');
            Route::delete('{note}/delete', 'NoteController@destroy')
                ->name('destroy');
        });

        Route::name('message.')->prefix('message')->group(function (): void {
            Route::get('', 'MessageController@index')
                ->name('index');
            Route::get('{message}', 'MessageController@show')
                ->name('show');
            Route::get('{message}/delete', 'MessageController@delete')
                ->name('delete');
            Route::delete('{message}/delete', 'MessageController@destroy')
                ->name('destroy');
        });
        Route::name('cv.')->prefix('cv')->group(function (): void {
            Route::get('', 'CVController@index')
                ->name('index');
            Route::get('create', 'CVController@create')
                ->name('create');
            Route::post('', 'CVController@store')
                ->name('store');
            Route::get('{cv}', 'CVController@show')
                ->name('show');
            Route::post('{cv}/sended', 'CVController@updateSendStatus')
                ->name('sended');
            Route::post('', 'CVController@store')
                ->name('store');
            Route::get('{cv}/edit', 'CVController@edit')
                    ->name('edit');
            Route::put('{cv}', 'CVController@update')
                    ->name('update');
            Route::get('{cv}/delete', 'CVController@delete')
                    ->name('delete');
            Route::delete('{cv}/delete', 'CVController@destroy')
                    ->name('destroy');
        });
        Route::name('category.')->prefix('category')->group(function (): void {
            Route::get('create', 'CategoryController@create')
                ->name('create');
            Route::post('', 'CategoryController@store')
                ->name('store');

            Route::get('{category}', 'CategoryController@edit')
                ->name('edit');
            Route::put('{category}', 'CategoryController@update')
                ->name('update');

            Route::get('{category}/delete', 'CategoryController@delete')
                ->name('delete');
            Route::delete('{category}/delete', 'CategoryController@destroy')
                ->name('destroy');
        });

        Route::name('project.')->prefix('project')->group(function (): void {
            Route::get('create', 'ProjectController@create')
                ->name('create');
            Route::post('', 'ProjectController@store')
                ->name('store');

            Route::get('{project}', 'ProjectController@edit')
                ->name('edit');
            Route::put('{project}', 'ProjectController@update')
                ->name('update');

            Route::get('{project}/delete', 'ProjectController@delete')
                ->name('delete');
            Route::delete('{project}/delete', 'ProjectController@destroy')
                ->name('destroy');
        });
    });

    Route::name('auth.')->namespace('Auth')->group(function (): void {
        Route::get('login', 'LoginController@login')
            ->name('login');
        Route::post('login', 'LoginController@authenticate')
            ->name('authenticate');
        Route::post('logout', 'LoginController@logout')
            ->name('logout');
    });
});
